==> teqp-0.18.0.tar.gz: teqp-0.18.0/externals/autodiff/docs/website/about.md <==
# About

## Philosophy

{{autodiff}} aims to be both *efficient* and *easy to use* C++ library for
automatic differentiation. If you appreciate how it has been developed so far,
and want to contribute, you are most welcome to join us in its development. And
if you dislike it, please let us know how we can improve!

You can contact us using our [Gitter Community Channel][gitter] or by creating
a new [GitHub Discussion][discussion]. If you would like to report a bug, then
please create a new [GitHub Issue][issues].

## License

MIT License

Copyright (c) 2018–2021 Allan Leal

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

[discussion]: https://github.com/autodiff/autodiff/discussions/new
[gitter]: https://gitter.im/autodiff/community
[issues]: https://github.com/autodiff/autodiff/issues/new

==> teqp-0.21.0.tar.gz: teqp-0.21.0/externals/autodiff/docs/website/about.md <==
# About

## Philosophy

{{autodiff}} aims to be both *efficient* and *easy to use* C++ library for
automatic differentiation. If you appreciate how it has been developed so far,
and want to contribute, you are most welcome to join us in its development. And
if you dislike it, please let us know how we can improve!

You can contact us using [GitHub Discussion][discussion]. If you would like to
report a bug, then please create a new [GitHub Issue][issues].

## License

MIT License

Copyright © 2018–2024 Allan Leal

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

[discussion]: https://github.com/autodiff/autodiff/discussions/new?category=q-a
[issues]: https://github.com/autodiff/autodiff/issues/new
